@@ -12,16 +12,13 @@ from .models import *
 @task()
 def reset_trigrams():
     files = os.listdir(settings.TRIGRAM_PATH)
-    c2 = (delete_all.si() | (group(load_trigram_file.si(f) for f in files)))
-    res = c2()
-    res.get()
+    delete_all()
+    for f in files:
+        load_trigram_file(f)
 
-
-@task()
 def delete_all():
     Trigram.objects.all().delete()
 
-@task()
 def load_trigram_file(f):
     trgs = []
     with open(os.path.join(settings.TRIGRAM_PATH,f),'r') as file_handle:
@@ -29,10 +26,4 @@ def load_trigram_file(f):
             l = line.strip().split("\t")
             words = l[0].split(" ")
             trgs.append([Trigram(word=words[-1],word_i_minus_one=words[1],word_i_minus_two=words[0],count=int(l[1]))])
-    if trgs != []:
-        g2 = add_trigram_records.chunks(trgs,100000).apply_async()
-
-
-@task()
-def add_trigram_records(tgs):
-    Trigram.objects.bulk_create(tgs)
+    rigram.objects.bulk_create(trgs)
